require 'rubygems'
require 'spec'
require 'webrat'

module Webrat #:nodoc:
  def self.session_class #:nodoc:
    TestSession
  end
 
  class TestSession < Session #:nodoc:
    attr_accessor :response_body
    attr_writer :response_code
 
    def doc_root
      File.expand_path(File.join(".", "public"))
    end
 
    def response
      @response ||= Object.new
    end
 
    def response_code
      @response_code || 200
    end
 
    def get(url, data, headers = nil)
    end
 
    def post(url, data, headers = nil)
    end
 
    def put(url, data, headers = nil)
    end
 
    def delete(url, data, headers = nil)
    end
  end
end

Spec::Runner.configure do |config|
  include Webrat::Methods

  def with_html(html)
    webrat_session.response_body = html
  end
end

Webrat.configure do |config|
  config.mode = :rails
end

describe "click_link issue" do

  it "should be able to find/click a link (without an html xmlns attribute)" do
    with_html <<-HTML
      <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

      <html>
        <head>
          <meta http-equiv="Content-Type" content="text/html; charset=us-ascii" />
          <title>test</title>
        </head>
        <body>
          <a href="link.html">Test</a>
        </body>
      </html>
    HTML

    lambda { click_link "Test" }.should_not raise_error(Webrat::NotFoundError)
  end


  it "should be able to find/click a link (with an html xmlns attribute)" do
    with_html <<-HTML
      <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

      <html xmlns="http://www.w3.org/1999/xhtml">
        <head>
          <meta http-equiv="Content-Type" content="text/html; charset=us-ascii" />
          <title>test</title>
        </head>
        <body>
          <a href="link.html">Test</a>
        </body>
      </html>
    HTML

    lambda { click_link "Test" }.should_not raise_error(Webrat::NotFoundError)
  end
  
end
